@@ -206,7 +206,7 @@ int ssl_sock_switchctx_cbk(SSL *ssl, int *al, void *arg)
 		}
 
 		if (!quic_transport_params_store(qc, 0, extension_data,
-		                                 extension_data + extension_len))
+		                                 extension_data + extension_len, 0))
 			goto abort;
 
 		qc->flags |= QUIC_FL_CONN_TX_TP_RECEIVED;
@@ -345,6 +345,38 @@ int ssl_sock_switchctx_cbk(SSL *ssl, int *al, void *arg)
 		TRACE_DEVEL("Sigalg parsing: has_rsa_sig (default)", SSL_EV_CONN_SWITCHCTX_CB, conn);
 		has_rsa_sig = 1;
 	}
+
+	if ((TRACE_SOURCE)->verbosity >= SSL_VERB_ADVANCED) {
+		if (TRACE_ENABLED(TRACE_LEVEL_DATA, SSL_EV_CONN_CIPHERS_EXT, conn, 0, 0, 0)) {
+			const uint8_t *cipher_suites;
+			size_t len;
+
+#if defined(OPENSSL_IS_BORINGSSL) || defined(OPENSSL_IS_AWSLC)
+			len = ctx->cipher_suites_len;
+			cipher_suites = ctx->cipher_suites;
+#else
+			len = SSL_client_hello_get0_ciphers(ssl, &cipher_suites);
+#endif
+			TRACE_DATA("Ciphers value", SSL_EV_CONN_CIPHERS_EXT, conn, ssl, cipher_suites, &len);
+		}
+
+		if (TRACE_ENABLED(TRACE_LEVEL_DATA, SSL_EV_CONN_CURVES_EXT, conn, 0, 0, 0)) {
+			const uint8_t *extension_data;
+			size_t extension_len;
+
+#if defined(OPENSSL_IS_BORINGSSL) || defined(OPENSSL_IS_AWSLC)
+			if (SSL_early_callback_ctx_extension_get(ctx, TLSEXT_TYPE_supported_groups,
+								 &extension_data, &extension_len)) {
+#else
+			if (SSL_client_hello_get0_ext(ssl, TLSEXT_TYPE_elliptic_curves,
+			                              &extension_data, &extension_len)) {
+#endif
+				if (extension_len)
+					TRACE_DATA("Elliptic curves", SSL_EV_CONN_CURVES_EXT, conn, extension_data, &extension_len);
+			}
+		}
+	}
+
 	if (has_ecdsa_sig) {  /* in very rare case: has ecdsa sign but not a ECDSA cipher */
 		const SSL_CIPHER *cipher;
 		STACK_OF(SSL_CIPHER) *ha_ciphers; /* haproxy side ciphers */
@@ -474,7 +506,8 @@ sni_lookup:
 	/* abort handshake (was SSL_TLSEXT_ERR_ALERT_FATAL) */
 	if (conn)
 		conn->err_code = CO_ER_SSL_HANDSHAKE;
-	TRACE_ERROR("No suitable SSL context found", SSL_EV_CONN_SWITCHCTX_CB|SSL_EV_CONN_ERR, conn, ssl, &conn->err_code);
+	TRACE_ERROR("No suitable SSL context found", SSL_EV_CONN_SWITCHCTX_CB|SSL_EV_CONN_ERR,
+	            conn, ssl, conn ? &conn->err_code : NULL);
 #if defined(OPENSSL_IS_BORINGSSL) || defined(OPENSSL_IS_AWSLC)
 	return ssl_select_cert_error;
 #else
@@ -533,7 +566,7 @@ int ssl_sock_switchctx_cbk(SSL *ssl, int *al, void *priv)
 		}
 
 		if (!quic_transport_params_store(qc, 0, extension_data,
-		                                 extension_data + extension_len))
+		                                 extension_data + extension_len, 0))
 			return SSL_TLSEXT_ERR_NOACK;
 
 		qc->flags |= QUIC_FL_CONN_TX_TP_RECEIVED;
